@@ -1,4 +1,6 @@
-CREATE TABLE IF NOT EXISTS schema_migration_log (
+CREATE SCHEMA cornac;
+
+CREATE TABLE IF NOT EXISTS cornac.schema_migration_log (
   version TEXT UNIQUE NOT NULL PRIMARY KEY,
   cdate TIMESTAMP DEFAULT NOW()
 );
