@@ -1,5 +1,5 @@
 -- cf. https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Overview.DBInstance.Status.html
-CREATE TYPE "db_instance_status" AS ENUM (
+CREATE TYPE cornac."db_instance_status" AS ENUM (
   'available',
   'backing-up',
   -- 'backtracking',  Only for Aurora.
@@ -30,11 +30,12 @@ CREATE TYPE "db_instance_status" AS ENUM (
   'upgrading'
 );
 
-CREATE TABLE db_instances (
+CREATE TABLE cornac.db_instances (
   id BIGSERIAL PRIMARY KEY,
   identifier TEXT UNIQUE,
-  status db_instance_status NOT NULL,
+  status cornac.db_instance_status NOT NULL,
   status_message TEXT,
+  recovery_token TEXT UNIQUE,
   "data" JSONb,
   iaas_data JSONb,
   operator_data JSONb
