@@ -8,16 +8,16 @@ class KnownError(Exception):
 
 
 class RemoteCommandError(Exception):
-    def __init__(self, message, exit_code, ssh_logs):
+    def __init__(self, message, exit_code, stderr):
         super().__init__(message)
         self.exit_code = exit_code
-        self.ssh_logs = ssh_logs
+        self.stderr = stderr
 
     @property
     def connection_closed_by_remote(self):
         return (
             self.exit_code == 255 and
-            'closed by remote host' in self.ssh_logs)
+            'closed by remote host' in self.stderr)
 
 
 class Timeout(Exception):
